@@ -82,8 +82,8 @@ We consider here the bar codes associated with the upper central series. It turn
 out that the non-trivial terms of the upper central series and the resulting factor
 groups are isomorphic::
 
-    sage: G158 = gap('SmallGroup(64,158)')
-    sage: G160 = gap('SmallGroup(64,160)')
+    sage: G158 = libgap.SmallGroup(64,158)
+    sage: G160 = libgap.SmallGroup(64,160)
     sage: [(G.IdGroup(), (G158/G).IdGroup()) for G in G158.UpperCentralSeries()]
     [([ 64, 158 ], [ 1, 1 ]),
      ([ 16, 2 ], [ 4, 2 ]),
@@ -508,7 +508,7 @@ class BarCode:
     whose entries are Poincaré series::
 
         sage: B.matrix()
-        [       -1/(t - 1)      -1/(t^2 - 1)                 1]
+        [       1/(-t + 1)      -1/(t^2 - 1)                 1]
         [                0 1/(t^2 - 2*t + 1)  (-t - 1)/(t - 1)]
         [                0                 0 1/(t^2 - 2*t + 1)]
 
@@ -620,7 +620,7 @@ class BarCode:
             sage: B
             Persistence data for H^*(D8; GF(2)) associated with UpperCentralSeries
             sage: B.data()
-            [((-1, -1), -1/(t - 1)),
+            [((-1, -1), 1/(-t + 1)),
              ((-1, 0), -1/(t^2 - 1)),
              ((-1, 1), 1),
              ((0, 0), 1/(t^2 - 2*t + 1)),
@@ -644,7 +644,7 @@ class BarCode:
             sage: H.make()
             sage: B = H.bar_code('UpperCentralSeries')
             sage: B.matrix()
-            [       -1/(t - 1)      -1/(t^2 - 1)                 1]
+            [       1/(-t + 1)      -1/(t^2 - 1)                 1]
             [                0 1/(t^2 - 2*t + 1)  (-t - 1)/(t - 1)]
             [                0                 0 1/(t^2 - 2*t + 1)]
 
